@@ -4,7 +4,7 @@ from __future__ import absolute_import
 
 Copyright (c) 1999-2004 Ng Pheng Siong. All rights reserved."""
 
-import socket
+import socket, os
 
 # M2Crypto
 from M2Crypto import _m2crypto as m2
@@ -23,15 +23,17 @@ m2.ssl_init(SSLError, SSLTimeoutError)
 from M2Crypto.SSL.Cipher import Cipher, Cipher_Stack
 from M2Crypto.SSL.Connection import Connection
 from M2Crypto.SSL.Context import Context
-from M2Crypto.SSL.SSLServer import (ForkingSSLServer, SSLServer,
-                                    ThreadingSSLServer)
-from M2Crypto.SSL.ssl_dispatcher import ssl_dispatcher
-from M2Crypto.SSL.timeout import timeout
+from M2Crypto.SSL.SSLServer import SSLServer, ThreadingSSLServer
+if os.name != 'nt':
+    from M2Crypto.SSL.SSLServer import ForkingSSLServer
+from M2Crypto.SSL.timeout import timeout, struct_to_timeout, struct_size
 
 verify_none = m2.SSL_VERIFY_NONE  # type: int
 verify_peer = m2.SSL_VERIFY_PEER  # type: int
 verify_fail_if_no_peer_cert = m2.SSL_VERIFY_FAIL_IF_NO_PEER_CERT  # type: int
 verify_client_once = m2.SSL_VERIFY_CLIENT_ONCE  # type: int
+verify_crl_check_chain = m2.VERIFY_CRL_CHECK_CHAIN # type: int
+verify_crl_check_leaf = m2.VERIFY_CRL_CHECK_LEAF # type: int
 
 SSL_SENT_SHUTDOWN = m2.SSL_SENT_SHUTDOWN  # type: int
 SSL_RECEIVED_SHUTDOWN = m2.SSL_RECEIVED_SHUTDOWN  # type: int
